@@ -100,9 +100,7 @@ def predict(
     arr = arr[:, :, :, 0]
     weights = weights[:, :, :, 0]
 
-    import pdb; pdb.set_trace()
-
-    weights_norm = (weights / np.sum(weights, axis=2))
+    weights_norm = (weights / np.sum(weights, axis=2, keepdims=True))
 
     merged = None
     if merge_method == "mean":
